@@ -15,6 +15,7 @@
 #' @importFrom utils txtProgressBar setTxtProgressBar
 #' @details The function \code{bssmle_se} estimates bootstrap standard errors for the estimated regression coefficients from the function \code{bssmle} or \code{bssmle_lt}.
 #' @return The function \code{bssmle_se} returns a list of components:
+#' \item{notconverged}{a list of number of bootstrap samples that did not converge}
 #' \item{numboot}{a number of bootstrap converged}
 #' \item{Sigma}{an estimated bootstrap variance-covariance matrix of the estimated regression coefficients}
 
@@ -28,8 +29,7 @@ bssmle_se <- function(formula, data, alpha, k = 1, do.par, nboot, objfun) {
   if (!isTRUE(do.par)) {
     res.bt <- foreach(j = 1:nboot,
                       .combine = "rbind",
-                      .export = c("naive_b", objfun),
-                      .packages = c("splines", "stats", "alabama", "utils")) %do% {
+                      .packages = c("intccr", "splines", "stats", "alabama", "utils")) %do% {
                         pb <- utils::txtProgressBar(title = "Progress bar for the bootstrapping",
                                                     min = 0, max = nboot, style = 3)
                         utils::setTxtProgressBar(pb, j)
@@ -46,12 +46,10 @@ bssmle_se <- function(formula, data, alpha, k = 1, do.par, nboot, objfun) {
   } else {
     no.cores <- parallel::detectCores() - 1
     clst <- parallel::makeCluster(no.cores)
-    #parallel::clusterExport(clst, c("Surv2", "bs.derivs", "dbs"))
     doParallel::registerDoParallel(clst)
 
     res.bt <- foreach(j = 1:nboot,
                       .combine = "rbind",
-                      #.export = c("naive_b", objfun),
                       .packages = c("intccr", "splines", "stats", "alabama", "utils")) %dopar% {
                         pb <- utils::txtProgressBar(title = "Progress bar for the bootstrapping",
                                                     min = 0, max = nboot, style = 3)
@@ -69,7 +67,7 @@ bssmle_se <- function(formula, data, alpha, k = 1, do.par, nboot, objfun) {
     parallel::stopCluster(clst)
     rownames(res.bt) <- c()
   }
-
+  rm(tmp)
   notconverged <- ifelse(is.vector(res.bt),
                          ifelse(!is.na(res.bt[1]), 0, 1),
                          if (sum(is.na(res.bt[, 1])) == 0) 0 else which(is.na(res.bt[, 1])))
